#!/bin/sh -e

# called by uscan with '--upstream-version' <version> <file>
DIR=openid4java-$2
TAR=openid4java_$2.orig.tar.gz

# Repack upstream source to tar.gz
tar zxvf $3
#mv openid4java-* $DIR
GZIP=--best tar czf $TAR -X debian/orig-tar.exclude $DIR
rm -rf $DIR $3
